find_homepage

Function find_homepage 

fn find_homepage(
    config: &DocConfig,
    root: &Path,
    sources: &Path,
) -> (String, Option<PathBuf>)
Locate the homepage markdown.

Returns (content, base_dir) where base_dir is the absolute directory the homepage file lives in (used to resolve its relative links). When no homepage file is found, returns an empty string and no base dir.