SourceToUrl

Type Alias SourceToUrl 

type SourceToUrl = HashMap<(String, String), String>;
Map from a Solidity source file location to its vocs page URL.

Key is (parent_dir_with_forward_slashes, file_stem) of the source file. Value is the root-relative vocs URL (no extension, leading /).

Aliased Type

struct SourceToUrl { /* private fields */ }

Layout

Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.

Size: 48 bytes